

# TrendFlow
TrendFlow is a deep-learning-based framework for analyzing the research trends.

Author: Tao Xiang

contact: tao.xiang@tum.de

## Doc
[[TrendFlow Doc](https://leoxiang66.github.io/research-trends-analysis/)]

## App on HuggingFace
[[TrendFlow App](https://huggingface.co/spaces/Adapting/TrendFlow)]







